# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/automation/v1/automation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.automation.v1 import action_pb2 as qwak_dot_automation_dot_v1_dot_action__pb2
from _qwak_proto.qwak.automation.v1 import trigger_pb2 as qwak_dot_automation_dot_v1_dot_trigger__pb2
from _qwak_proto.qwak.automation.v1 import notification_pb2 as qwak_dot_automation_dot_v1_dot_notification__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#qwak/automation/v1/automation.proto\x12\x12qwak.automation.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1fqwak/automation/v1/action.proto\x1a qwak/automation/v1/trigger.proto\x1a%qwak/automation/v1/notification.proto\"\xcc\x01\n\nAutomation\x12\x15\n\rautomation_id\x18\x01 \x01(\t\x12;\n\x0f\x61utomation_spec\x18\x02 \x01(\x0b\x32\".qwak.automation.v1.AutomationSpec\x12\x1b\n\x13qwak_environment_id\x18\x03 \x01(\t\x12\x39\n\x0c\x63reate_audit\x18\x04 \x01(\x0b\x32#.qwak.automation.v1.AutomationAudit\x12\x12\n\nis_deleted\x18\x05 \x01(\x08\"\xe3\x02\n\x0e\x41utomationSpec\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x17\n\x0f\x61utomation_name\x18\x03 \x01(\t\x12,\n\x07trigger\x18\x04 \x01(\x0b\x32\x1b.qwak.automation.v1.Trigger\x12*\n\x06\x61\x63tion\x18\x05 \x01(\x0b\x32\x1a.qwak.automation.v1.Action\x12\x1e\n\x16\x61utomation_description\x18\x06 \x01(\t\x12\x12\n\nis_enabled\x18\x07 \x01(\x08\x12\x32\n\x08on_error\x18\x08 \x01(\x0b\x32 .qwak.automation.v1.Notification\x12\x34\n\non_success\x18\t \x01(\x0b\x32 .qwak.automation.v1.Notification\x12\x1b\n\x13\x65xecute_immediately\x18\n \x01(\x08\x12\x11\n\tis_sdk_v1\x18\x0b \x01(\x08\"L\n\x0f\x41utomationAudit\x12(\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07user_id\x18\x02 \x01(\tB!\n\x1d\x63om.qwak.ai.automation.api.v1P\x01\x62\x06proto3')



_AUTOMATION = DESCRIPTOR.message_types_by_name['Automation']
_AUTOMATIONSPEC = DESCRIPTOR.message_types_by_name['AutomationSpec']
_AUTOMATIONAUDIT = DESCRIPTOR.message_types_by_name['AutomationAudit']
Automation = _reflection.GeneratedProtocolMessageType('Automation', (_message.Message,), {
  'DESCRIPTOR' : _AUTOMATION,
  '__module__' : 'qwak.automation.v1.automation_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.Automation)
  })
_sym_db.RegisterMessage(Automation)

AutomationSpec = _reflection.GeneratedProtocolMessageType('AutomationSpec', (_message.Message,), {
  'DESCRIPTOR' : _AUTOMATIONSPEC,
  '__module__' : 'qwak.automation.v1.automation_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.AutomationSpec)
  })
_sym_db.RegisterMessage(AutomationSpec)

AutomationAudit = _reflection.GeneratedProtocolMessageType('AutomationAudit', (_message.Message,), {
  'DESCRIPTOR' : _AUTOMATIONAUDIT,
  '__module__' : 'qwak.automation.v1.automation_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.AutomationAudit)
  })
_sym_db.RegisterMessage(AutomationAudit)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.qwak.ai.automation.api.v1P\001'
  _AUTOMATION._serialized_start=199
  _AUTOMATION._serialized_end=403
  _AUTOMATIONSPEC._serialized_start=406
  _AUTOMATIONSPEC._serialized_end=761
  _AUTOMATIONAUDIT._serialized_start=763
  _AUTOMATIONAUDIT._serialized_end=839
# @@protoc_insertion_point(module_scope)
