"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class PagerdutyIntegration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENCRYPTED_PAGERDUTY_AUTH_CONFIG_FIELD_NUMBER: builtins.int
    ENDPOINT_URL_FIELD_NUMBER: builtins.int
    PAGERDUTY_SYSTEM_SECRET_FIELD_NUMBER: builtins.int
    @property
    def encrypted_pagerduty_auth_config(self) -> global___PagerdutyAuthConfig:
        """Encrypted Pagerduty auth configuration"""
    endpoint_url: builtins.str
    """Pagerduty endpoint url. Determined by the Api version"""
    @property
    def pagerduty_system_secret(self) -> global___PagerdutySystemSecretDescriptor:
        """Pagerduty system secret descriptor"""
    def __init__(
        self,
        *,
        encrypted_pagerduty_auth_config: global___PagerdutyAuthConfig | None = ...,
        endpoint_url: builtins.str = ...,
        pagerduty_system_secret: global___PagerdutySystemSecretDescriptor | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth", "encrypted_pagerduty_auth_config", b"encrypted_pagerduty_auth_config", "pagerduty_system_secret", b"pagerduty_system_secret"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "encrypted_pagerduty_auth_config", b"encrypted_pagerduty_auth_config", "endpoint_url", b"endpoint_url", "pagerduty_system_secret", b"pagerduty_system_secret"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth", b"auth"]) -> typing_extensions.Literal["pagerduty_system_secret"] | None: ...

global___PagerdutyIntegration = PagerdutyIntegration

class PagerdutyIntegrationSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGERDUTY_AUTH_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def pagerduty_auth_configuration(self) -> global___PagerdutyAuthConfig: ...
    def __init__(
        self,
        *,
        pagerduty_auth_configuration: global___PagerdutyAuthConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth", "pagerduty_auth_configuration", b"pagerduty_auth_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "pagerduty_auth_configuration", b"pagerduty_auth_configuration"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth", b"auth"]) -> typing_extensions.Literal["pagerduty_auth_configuration"] | None: ...

global___PagerdutyIntegrationSpec = PagerdutyIntegrationSpec

class PagerdutyAuthConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENTS_V1_AUTH_CONFIG_FIELD_NUMBER: builtins.int
    EVENTS_V2_AUTH_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def events_v1_auth_config(self) -> global___PagerdutyEventsV1AuthConfig:
        """Pagerduty events V1 Auth Config"""
    @property
    def events_v2_auth_config(self) -> global___PagerdutyEventsV2AuthConfig:
        """Pagerduty events V2 Auth Config"""
    def __init__(
        self,
        *,
        events_v1_auth_config: global___PagerdutyEventsV1AuthConfig | None = ...,
        events_v2_auth_config: global___PagerdutyEventsV2AuthConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth", "events_v1_auth_config", b"events_v1_auth_config", "events_v2_auth_config", b"events_v2_auth_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "events_v1_auth_config", b"events_v1_auth_config", "events_v2_auth_config", b"events_v2_auth_config"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth", b"auth"]) -> typing_extensions.Literal["events_v1_auth_config", "events_v2_auth_config"] | None: ...

global___PagerdutyAuthConfig = PagerdutyAuthConfig

class PagerdutyEventsV1AuthConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_KEY_FIELD_NUMBER: builtins.int
    service_key: builtins.str
    """Pagerduty service key"""
    def __init__(
        self,
        *,
        service_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["service_key", b"service_key"]) -> None: ...

global___PagerdutyEventsV1AuthConfig = PagerdutyEventsV1AuthConfig

class PagerdutyEventsV2AuthConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROUTING_KEY_FIELD_NUMBER: builtins.int
    routing_key: builtins.str
    """Pagerduty routing key"""
    def __init__(
        self,
        *,
        routing_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["routing_key", b"routing_key"]) -> None: ...

global___PagerdutyEventsV2AuthConfig = PagerdutyEventsV2AuthConfig

class PagerdutySystemSecretDescriptor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_NAME_FIELD_NUMBER: builtins.int
    PAGERDUTY_EVENTS_V1_SYSTEM_SECRET_FIELD_NUMBER: builtins.int
    PAGERDUTY_EVENTS_V2_SYSTEM_SECRET_FIELD_NUMBER: builtins.int
    secret_name: builtins.str
    """Pagerduty system secret name"""
    @property
    def pagerduty_events_v1_system_secret(self) -> global___PagerdutyEventsV1SystemSecretDescriptor:
        """Pagerduty v1 system secret descriptor"""
    @property
    def pagerduty_events_v2_system_secret(self) -> global___PagerdutyEventsV2SystemSecretDescriptor:
        """Pagerduty v2 system secret descriptor"""
    def __init__(
        self,
        *,
        secret_name: builtins.str = ...,
        pagerduty_events_v1_system_secret: global___PagerdutyEventsV1SystemSecretDescriptor | None = ...,
        pagerduty_events_v2_system_secret: global___PagerdutyEventsV2SystemSecretDescriptor | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagerduty_events_v1_system_secret", b"pagerduty_events_v1_system_secret", "pagerduty_events_v2_system_secret", b"pagerduty_events_v2_system_secret", "pagerduty_secret", b"pagerduty_secret"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagerduty_events_v1_system_secret", b"pagerduty_events_v1_system_secret", "pagerduty_events_v2_system_secret", b"pagerduty_events_v2_system_secret", "pagerduty_secret", b"pagerduty_secret", "secret_name", b"secret_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["pagerduty_secret", b"pagerduty_secret"]) -> typing_extensions.Literal["pagerduty_events_v1_system_secret", "pagerduty_events_v2_system_secret"] | None: ...

global___PagerdutySystemSecretDescriptor = PagerdutySystemSecretDescriptor

class PagerdutyEventsV1SystemSecretDescriptor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_KEY_SECRET_KEY_FIELD_NUMBER: builtins.int
    service_key_secret_key: builtins.str
    """Pagerduty system secret service_key secret key"""
    def __init__(
        self,
        *,
        service_key_secret_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["service_key_secret_key", b"service_key_secret_key"]) -> None: ...

global___PagerdutyEventsV1SystemSecretDescriptor = PagerdutyEventsV1SystemSecretDescriptor

class PagerdutyEventsV2SystemSecretDescriptor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROUTING_KEY_SECRET_KEY_FIELD_NUMBER: builtins.int
    routing_key_secret_key: builtins.str
    """Pagerduty system secret routing_key secret key"""
    def __init__(
        self,
        *,
        routing_key_secret_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["routing_key_secret_key", b"routing_key_secret_key"]) -> None: ...

global___PagerdutyEventsV2SystemSecretDescriptor = PagerdutyEventsV2SystemSecretDescriptor

class PagerdutyValidationSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGERDUTY_AUTH_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def pagerduty_auth_config(self) -> global___PagerdutyAuthConfig:
        """Pagerduty auth config"""
    def __init__(
        self,
        *,
        pagerduty_auth_config: global___PagerdutyAuthConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagerduty_auth_config", b"pagerduty_auth_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagerduty_auth_config", b"pagerduty_auth_config"]) -> None: ...

global___PagerdutyValidationSpec = PagerdutyValidationSpec

class PagerdutyIntegrationOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PagerdutyIntegrationOptions = PagerdutyIntegrationOptions
