# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.deployment import alert_service_pb2 as qwak_dot_deployment_dot_alert__service__pb2


class AlertManagementServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetAlertsConfiguration = channel.unary_unary(
                '/qwak.deployment.management.AlertManagementService/GetAlertsConfiguration',
                request_serializer=qwak_dot_deployment_dot_alert__service__pb2.GetAlertsConfigurationRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_alert__service__pb2.GetAlertsConfigurationResponse.FromString,
                )
        self.ApplyAlertsConfiguration = channel.unary_unary(
                '/qwak.deployment.management.AlertManagementService/ApplyAlertsConfiguration',
                request_serializer=qwak_dot_deployment_dot_alert__service__pb2.ApplyAlertsConfigurationRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_alert__service__pb2.ApplyAlertsConfigurationResponse.FromString,
                )
        self.GetNotificationChannelsList = channel.unary_unary(
                '/qwak.deployment.management.AlertManagementService/GetNotificationChannelsList',
                request_serializer=qwak_dot_deployment_dot_alert__service__pb2.GetNotificationChannelsListRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_alert__service__pb2.GetNotificationChannelsListResponse.FromString,
                )
        self.ApplyNotificationChannel = channel.unary_unary(
                '/qwak.deployment.management.AlertManagementService/ApplyNotificationChannel',
                request_serializer=qwak_dot_deployment_dot_alert__service__pb2.ApplyNotificationChannelRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_alert__service__pb2.ApplyNotificationChannelResponse.FromString,
                )
        self.DeleteNotificationChannel = channel.unary_unary(
                '/qwak.deployment.management.AlertManagementService/DeleteNotificationChannel',
                request_serializer=qwak_dot_deployment_dot_alert__service__pb2.DeleteNotificationChannelRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_alert__service__pb2.DeleteNotificationChannelResponse.FromString,
                )
        self.GetNotificationChannelDetailsList = channel.unary_unary(
                '/qwak.deployment.management.AlertManagementService/GetNotificationChannelDetailsList',
                request_serializer=qwak_dot_deployment_dot_alert__service__pb2.GetNotificationChannelDetailsListRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_alert__service__pb2.GetNotificationChannelDetailsListResponse.FromString,
                )


class AlertManagementServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetAlertsConfiguration(self, request, context):
        """Get alerts for deployed model
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ApplyAlertsConfiguration(self, request, context):
        """Update configuration for alerts in deployment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNotificationChannelsList(self, request, context):
        """Get The Notification Channels list
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ApplyNotificationChannel(self, request, context):
        """Channels to add or update
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteNotificationChannel(self, request, context):
        """Delete notification channel
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNotificationChannelDetailsList(self, request, context):
        """Get Full Details for channels
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AlertManagementServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetAlertsConfiguration': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAlertsConfiguration,
                    request_deserializer=qwak_dot_deployment_dot_alert__service__pb2.GetAlertsConfigurationRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_alert__service__pb2.GetAlertsConfigurationResponse.SerializeToString,
            ),
            'ApplyAlertsConfiguration': grpc.unary_unary_rpc_method_handler(
                    servicer.ApplyAlertsConfiguration,
                    request_deserializer=qwak_dot_deployment_dot_alert__service__pb2.ApplyAlertsConfigurationRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_alert__service__pb2.ApplyAlertsConfigurationResponse.SerializeToString,
            ),
            'GetNotificationChannelsList': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNotificationChannelsList,
                    request_deserializer=qwak_dot_deployment_dot_alert__service__pb2.GetNotificationChannelsListRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_alert__service__pb2.GetNotificationChannelsListResponse.SerializeToString,
            ),
            'ApplyNotificationChannel': grpc.unary_unary_rpc_method_handler(
                    servicer.ApplyNotificationChannel,
                    request_deserializer=qwak_dot_deployment_dot_alert__service__pb2.ApplyNotificationChannelRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_alert__service__pb2.ApplyNotificationChannelResponse.SerializeToString,
            ),
            'DeleteNotificationChannel': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteNotificationChannel,
                    request_deserializer=qwak_dot_deployment_dot_alert__service__pb2.DeleteNotificationChannelRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_alert__service__pb2.DeleteNotificationChannelResponse.SerializeToString,
            ),
            'GetNotificationChannelDetailsList': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNotificationChannelDetailsList,
                    request_deserializer=qwak_dot_deployment_dot_alert__service__pb2.GetNotificationChannelDetailsListRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_alert__service__pb2.GetNotificationChannelDetailsListResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.deployment.management.AlertManagementService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AlertManagementService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetAlertsConfiguration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.AlertManagementService/GetAlertsConfiguration',
            qwak_dot_deployment_dot_alert__service__pb2.GetAlertsConfigurationRequest.SerializeToString,
            qwak_dot_deployment_dot_alert__service__pb2.GetAlertsConfigurationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ApplyAlertsConfiguration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.AlertManagementService/ApplyAlertsConfiguration',
            qwak_dot_deployment_dot_alert__service__pb2.ApplyAlertsConfigurationRequest.SerializeToString,
            qwak_dot_deployment_dot_alert__service__pb2.ApplyAlertsConfigurationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNotificationChannelsList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.AlertManagementService/GetNotificationChannelsList',
            qwak_dot_deployment_dot_alert__service__pb2.GetNotificationChannelsListRequest.SerializeToString,
            qwak_dot_deployment_dot_alert__service__pb2.GetNotificationChannelsListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ApplyNotificationChannel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.AlertManagementService/ApplyNotificationChannel',
            qwak_dot_deployment_dot_alert__service__pb2.ApplyNotificationChannelRequest.SerializeToString,
            qwak_dot_deployment_dot_alert__service__pb2.ApplyNotificationChannelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteNotificationChannel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.AlertManagementService/DeleteNotificationChannel',
            qwak_dot_deployment_dot_alert__service__pb2.DeleteNotificationChannelRequest.SerializeToString,
            qwak_dot_deployment_dot_alert__service__pb2.DeleteNotificationChannelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNotificationChannelDetailsList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.AlertManagementService/GetNotificationChannelDetailsList',
            qwak_dot_deployment_dot_alert__service__pb2.GetNotificationChannelDetailsListRequest.SerializeToString,
            qwak_dot_deployment_dot_alert__service__pb2.GetNotificationChannelDetailsListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
