# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/execution/v1/batch.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dqwak/execution/v1/batch.proto\x12\x1fqwak.feature.store.execution.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd3\x01\n\x0e\x42\x61tchIngestion\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x01 \x01(\t\x12H\n\x0emanual_trigger\x18\x02 \x01(\x0b\x32..qwak.feature.store.execution.v1.ManualTriggerH\x00\x12N\n\x11scheduled_trigger\x18\x03 \x01(\x0b\x32\x31.qwak.feature.store.execution.v1.ScheduledTriggerH\x00\x42\x0e\n\x0ctrigger_type\"A\n\rManualTrigger\x12\x30\n\x0ctrigger_date\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"J\n\x10ScheduledTrigger\x12\x36\n\x12logical_batch_date\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB)\n%com.qwak.ai.features.execution.api.v1P\x01\x62\x06proto3')



_BATCHINGESTION = DESCRIPTOR.message_types_by_name['BatchIngestion']
_MANUALTRIGGER = DESCRIPTOR.message_types_by_name['ManualTrigger']
_SCHEDULEDTRIGGER = DESCRIPTOR.message_types_by_name['ScheduledTrigger']
BatchIngestion = _reflection.GeneratedProtocolMessageType('BatchIngestion', (_message.Message,), {
  'DESCRIPTOR' : _BATCHINGESTION,
  '__module__' : 'qwak.execution.v1.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.BatchIngestion)
  })
_sym_db.RegisterMessage(BatchIngestion)

ManualTrigger = _reflection.GeneratedProtocolMessageType('ManualTrigger', (_message.Message,), {
  'DESCRIPTOR' : _MANUALTRIGGER,
  '__module__' : 'qwak.execution.v1.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.ManualTrigger)
  })
_sym_db.RegisterMessage(ManualTrigger)

ScheduledTrigger = _reflection.GeneratedProtocolMessageType('ScheduledTrigger', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULEDTRIGGER,
  '__module__' : 'qwak.execution.v1.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.ScheduledTrigger)
  })
_sym_db.RegisterMessage(ScheduledTrigger)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.features.execution.api.v1P\001'
  _BATCHINGESTION._serialized_start=100
  _BATCHINGESTION._serialized_end=311
  _MANUALTRIGGER._serialized_start=313
  _MANUALTRIGGER._serialized_end=378
  _SCHEDULEDTRIGGER._serialized_start=380
  _SCHEDULEDTRIGGER._serialized_end=454
# @@protoc_insertion_point(module_scope)
