"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class FeaturesetDeletion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BATCH_FEATURESET_DELETION_FIELD_NUMBER: builtins.int
    STREAMING_FEATURESET_DELETION_FIELD_NUMBER: builtins.int
    STREAMING_AGGREGATION_FEATURESET_DELETION_FIELD_NUMBER: builtins.int
    @property
    def batch_featureset_deletion(self) -> global___BatchFeaturesetDeletion: ...
    @property
    def streaming_featureset_deletion(self) -> global___StreamingFeaturesetDeletion: ...
    @property
    def streaming_aggregation_featureset_deletion(self) -> global___StreamingAggregationFeaturesetDeletion: ...
    def __init__(
        self,
        *,
        batch_featureset_deletion: global___BatchFeaturesetDeletion | None = ...,
        streaming_featureset_deletion: global___StreamingFeaturesetDeletion | None = ...,
        streaming_aggregation_featureset_deletion: global___StreamingAggregationFeaturesetDeletion | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["batch_featureset_deletion", b"batch_featureset_deletion", "deletion_type", b"deletion_type", "streaming_aggregation_featureset_deletion", b"streaming_aggregation_featureset_deletion", "streaming_featureset_deletion", b"streaming_featureset_deletion"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["batch_featureset_deletion", b"batch_featureset_deletion", "deletion_type", b"deletion_type", "streaming_aggregation_featureset_deletion", b"streaming_aggregation_featureset_deletion", "streaming_featureset_deletion", b"streaming_featureset_deletion"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["deletion_type", b"deletion_type"]) -> typing_extensions.Literal["batch_featureset_deletion", "streaming_featureset_deletion", "streaming_aggregation_featureset_deletion"] | None: ...

global___FeaturesetDeletion = FeaturesetDeletion

class BatchFeaturesetDeletion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___BatchFeaturesetDeletion = BatchFeaturesetDeletion

class StreamingFeaturesetDeletion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StreamingFeaturesetDeletion = StreamingFeaturesetDeletion

class StreamingAggregationFeaturesetDeletion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StreamingAggregationFeaturesetDeletion = StreamingAggregationFeaturesetDeletion
