# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/v1/common/source_code/source_code.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:qwak/feature_store/v1/common/source_code/source_code.proto\x12(qwak.feature.store.v1.common.source_code\"`\n\x0eSourceCodeSpec\x12N\n\x08\x61rtifact\x18\x01 \x01(\x0b\x32<.qwak.feature.store.v1.common.source_code.SourceCodeArtifact\"k\n\x12SourceCodeArtifact\x12M\n\x0czip_artifact\x18\x01 \x01(\x0b\x32\x35.qwak.feature.store.v1.common.source_code.ZipArtifactH\x00\x42\x06\n\x04type\".\n\x0bZipArtifact\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x11\n\tmain_file\x18\x02 \x01(\tB3\n/com.qwak.ai.feature.store.v1.common.source_codeP\x01\x62\x06proto3')



_SOURCECODESPEC = DESCRIPTOR.message_types_by_name['SourceCodeSpec']
_SOURCECODEARTIFACT = DESCRIPTOR.message_types_by_name['SourceCodeArtifact']
_ZIPARTIFACT = DESCRIPTOR.message_types_by_name['ZipArtifact']
SourceCodeSpec = _reflection.GeneratedProtocolMessageType('SourceCodeSpec', (_message.Message,), {
  'DESCRIPTOR' : _SOURCECODESPEC,
  '__module__' : 'qwak.feature_store.v1.common.source_code.source_code_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.v1.common.source_code.SourceCodeSpec)
  })
_sym_db.RegisterMessage(SourceCodeSpec)

SourceCodeArtifact = _reflection.GeneratedProtocolMessageType('SourceCodeArtifact', (_message.Message,), {
  'DESCRIPTOR' : _SOURCECODEARTIFACT,
  '__module__' : 'qwak.feature_store.v1.common.source_code.source_code_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.v1.common.source_code.SourceCodeArtifact)
  })
_sym_db.RegisterMessage(SourceCodeArtifact)

ZipArtifact = _reflection.GeneratedProtocolMessageType('ZipArtifact', (_message.Message,), {
  'DESCRIPTOR' : _ZIPARTIFACT,
  '__module__' : 'qwak.feature_store.v1.common.source_code.source_code_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.v1.common.source_code.ZipArtifact)
  })
_sym_db.RegisterMessage(ZipArtifact)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n/com.qwak.ai.feature.store.v1.common.source_codeP\001'
  _SOURCECODESPEC._serialized_start=104
  _SOURCECODESPEC._serialized_end=200
  _SOURCECODEARTIFACT._serialized_start=202
  _SOURCECODEARTIFACT._serialized_end=309
  _ZIPARTIFACT._serialized_start=311
  _ZIPARTIFACT._serialized_end=357
# @@protoc_insertion_point(module_scope)
